defmodule TechRadarEditor.RadarDataPointControllerTest do
  use TechRadarEditor.ConnCase

  alias TechRadarEditor.RadarDataPoint
  @valid_attrs %{cycle: 2, description: "some content", is_new: true, name: "some content", quadrant: 2}
  @invalid_attrs %{}

  test "lists all entries on index", %{conn: conn} do
    conn = get conn, radar_data_point_path(conn, :index)
    assert html_response(conn, 200) =~ "Listing radar data point"
  end

  test "renders form for new resources", %{conn: conn} do
    conn = get conn, radar_data_point_path(conn, :new)
    assert html_response(conn, 200) =~ "New radar data point"
  end

  test "creates resource and redirects when data is valid", %{conn: conn} do
    conn = post conn, radar_data_point_path(conn, :create), radar_data_point: @valid_attrs
    assert redirected_to(conn) == radar_data_point_path(conn, :index)
    assert Repo.get_by(RadarDataPoint, @valid_attrs)
  end

  test "does not create resource and renders errors when data is invalid", %{conn: conn} do
    conn = post conn, radar_data_point_path(conn, :create), radar_data_point: @invalid_attrs
    assert html_response(conn, 200) =~ "New radar data point"
  end

  test "shows chosen resource", %{conn: conn} do
    radar_data_point = Repo.insert! %RadarDataPoint{}
    conn = get conn, radar_data_point_path(conn, :show, radar_data_point)
    assert html_response(conn, 200) =~ "Show radar data point"
  end

  test "renders page not found when id is nonexistent", %{conn: conn} do
    assert_error_sent 404, fn ->
      get conn, radar_data_point_path(conn, :show, -1)
    end
  end

  test "renders form for editing chosen resource", %{conn: conn} do
    radar_data_point = Repo.insert! %RadarDataPoint{}
    conn = get conn, radar_data_point_path(conn, :edit, radar_data_point)
    assert html_response(conn, 200) =~ "Edit radar data point"
  end

  test "updates chosen resource and redirects when data is valid", %{conn: conn} do
    radar_data_point = Repo.insert! %RadarDataPoint{}
    conn = put conn, radar_data_point_path(conn, :update, radar_data_point), radar_data_point: @valid_attrs
    assert redirected_to(conn) == radar_data_point_path(conn, :show, radar_data_point)
    assert Repo.get_by(RadarDataPoint, @valid_attrs)
  end

  test "does not update chosen resource and renders errors when data is invalid", %{conn: conn} do
    radar_data_point = Repo.insert! %RadarDataPoint{}
    conn = put conn, radar_data_point_path(conn, :update, radar_data_point), radar_data_point: @invalid_attrs
    assert html_response(conn, 200) =~ "Edit radar data point"
  end

  test "deletes chosen resource", %{conn: conn} do
    radar_data_point = Repo.insert! %RadarDataPoint{}
    conn = delete conn, radar_data_point_path(conn, :delete, radar_data_point)
    assert redirected_to(conn) == radar_data_point_path(conn, :index)
    refute Repo.get(RadarDataPoint, radar_data_point.id)
  end
end
