defmodule TechRadarEditor.RadarDataPointController do
  use TechRadarEditor.Web, :controller

  alias TechRadarEditor.RadarDataPoint

  def index(conn, _params) do
    radar_data_point = Repo.all(RadarDataPoint)
    render(conn, "index.html", radar_data_point: radar_data_point)
  end

  def new(conn, _params) do
    changeset = RadarDataPoint.changeset(%RadarDataPoint{})
    render(conn, "new.html", changeset: changeset)
  end

  def create(conn, %{"radar_data_point" => radar_data_point_params}) do
    changeset = RadarDataPoint.changeset(%RadarDataPoint{}, radar_data_point_params)

    case Repo.insert(changeset) do
      {:ok, _radar_data_point} ->
        conn
        |> put_flash(:info, "Radar data point created successfully.")
        |> redirect(to: radar_data_point_path(conn, :index))
      {:error, changeset} ->
        render(conn, "new.html", changeset: changeset)
    end
  end

  def show(conn, %{"id" => id}) do
    radar_data_point = Repo.get!(RadarDataPoint, id)
    render(conn, "show.html", radar_data_point: radar_data_point)
  end

  def edit(conn, %{"id" => id}) do
    radar_data_point = Repo.get!(RadarDataPoint, id)
    changeset = RadarDataPoint.changeset(radar_data_point)
    render(conn, "edit.html", radar_data_point: radar_data_point, changeset: changeset)
  end

  def update(conn, %{"id" => id, "radar_data_point" => radar_data_point_params}) do
    radar_data_point = Repo.get!(RadarDataPoint, id)
    changeset = RadarDataPoint.changeset(radar_data_point, radar_data_point_params)

    case Repo.update(changeset) do
      {:ok, radar_data_point} ->
        conn
        |> put_flash(:info, "Radar data point updated successfully.")
        |> redirect(to: radar_data_point_path(conn, :show, radar_data_point))
      {:error, changeset} ->
        render(conn, "edit.html", radar_data_point: radar_data_point, changeset: changeset)
    end
  end

  def delete(conn, %{"id" => id}) do
    radar_data_point = Repo.get!(RadarDataPoint, id)

    # Here we use delete! (with a bang) because we expect
    # it to always work (and if it does not, it will raise).
    Repo.delete!(radar_data_point)

    conn
    |> put_flash(:info, "Radar data point deleted successfully.")
    |> redirect(to: radar_data_point_path(conn, :index))
  end
end
